//
//  FeedListCoordinator.swift
//  ReviewsFeed
//
//  Created by Javier Cicchelli on 21/03/2024.
//  Copyright © 2024 Röck+Cöde. All rights reserved.
//

import Foundation
import ReviewsCoordinationKit

public final class FeedListCoordinator: Coordinator {

    // MARK: Constants
    public let router: any Router
    
    private let configuration: FeedListConfiguration
    
    // MARK: Properties
    public var children: [any Coordinator] = []
    
    lazy var viewController = {
        FeedListViewController(.init(
            configuration: configuration,
            coordination: self
        ))
    }()
    
    // MARK: Initialisers
    public init(
        configuration: FeedListConfiguration,
        router: any Router
    ) {
        self.configuration = configuration
        self.router = router
    }
    
    // MARK: Functions
    public func present(
        animated: Bool,
        onDismiss: Router.OnDismissClosure? = nil
    ) {
        router.present(
            viewController,
            animated: animated,
            onDismiss: onDismiss
        )
    }
    
}

// MARK: - FeedListCoordination
extension FeedListCoordinator: FeedListCoordination {
    
    // MARK: Functions
    func open(_ item: Review) {
        present(
            child: FeedItemCoordinator(
                item: item,
                router: SheetRouter(parentViewController: viewController)
            ),
            animated: true
        )
    }
    
}
