//
//  TopWordsUseCase.swift
//  ReviewsParserKit
//
//  Created by Javier Cicchelli on 18/03/2024.
//  Copyright © 2024 Röck+Cöde VoF. All rights reserved.
//

import Foundation

public struct TopWordsUseCase {
    
    // MARK: Type aliases
    public typealias Input = [[WordCount]]
    public typealias Output = [WordCount]
    
    // MARK: Initialisers
    public init() {}
    
    // MARK: Functions
    public func callAsFunction(_ input: Input) -> Output {
        let wordCounts = input
            .reduce([WordCount](), +)
            .reduce(into: [WordCount]()) { partialResult, wordCount in
                guard
                    let wordCountFound = partialResult.first(where: { $0.word == wordCount.word })
                else {
                    partialResult.append(wordCount)
                    return
                }
                
                partialResult.removeAll { $0 == wordCountFound }
                partialResult.append(.init(
                    word: wordCount.word,
                    count: wordCount.count + wordCountFound.count
                ))
            }
            .sorted {
                guard $0.count != $1.count else {
                    return $0.word.token < $1.word.token
                }
                
                return $0.count > $1.count
            }

        return wordCounts.count >= .Max.words
            ? Array(wordCounts[0...2])
            : wordCounts
    }
    
}

// MARK: - Int+Constants
private extension Int {
    enum Max {
        static let words: Int = 3
    }
}
