//
//  TopWordsUseCaseTests.swift
//  ReviewsFilterTest
//
//  Created by Javier Cicchelli on 18/03/2024.
//  Copyright © 2024 Röck+Cöde VoF. All rights reserved.
//

import ReviewsFilterKit
import XCTest

final class TopWordsUseCaseTests: XCTestCase {
    
    // MARK: Properties
    private var input: TopWordsUseCase.Input!
    private var output: TopWordsUseCase.Output!
    private var sut: TopWordsUseCase!
    
    // MARK: Setup
    override func setUp() async throws {
        sut = .init()
    }
    
    // MARK: Functions
    func testCallAsFunction_withInput_hasDifferentWords() {
        // GIVEN
        input = [[
            .init(word: .init(term: "One", token: "one"), count: 3)
        ], [
            .init(word: .init(term: "Two", token: "two"), count: 1)
        ], [
            .init(word: .init(term: "Three", token: "three"), count: 5),
            .init(word: .init(term: "Four", token: "four"), count: 2),
        ]]
        
        // WHEN
        output = sut(input)
        
        // THEN
        XCTAssertFalse(output.isEmpty)
        XCTAssertEqual(output.count, 3)
        XCTAssertEqual(output, [
            .init(word: .init(term: "Three", token: "three"), count: 5),
            .init(word: .init(term: "One", token: "one"), count: 3),
            .init(word: .init(term: "Four", token: "four"), count: 2)
        ])
    }
    
    func testCallAsFunction_withInput_hasSomeCommonWords() {
        // GIVEN
        input = [[
            .init(word: .init(term: "One", token: "one"), count: 3),
            .init(word: .init(term: "Two", token: "two"), count: 7),
            .init(word: .init(term: "Three", token: "three"), count: 1),
        ], [
            .init(word: .init(term: "Four", token: "four"), count: 5),
            .init(word: .init(term: "Two", token: "two"), count: 2),
            .init(word: .init(term: "Five", token: "five"), count: 6),
        ], [
            .init(word: .init(term: "Six", token: "six"), count: 9),
            .init(word: .init(term: "Four", token: "four"), count: 4),
            .init(word: .init(term: "Two", token: "two"), count: 1),
        ]]
        
        // WHEN
        output = sut(input)
        
        // THEN
        XCTAssertFalse(output.isEmpty)
        XCTAssertEqual(output.count, 3)
        XCTAssertEqual(output, [
            .init(word: .init(term: "Two", token: "two"), count: 10),
            .init(word: .init(term: "Four", token: "four"), count: 9),
            .init(word: .init(term: "Six", token: "six"), count: 9)
        ])
    }
    
    func testCallAsFunction_withInput_hasFewWords() {
        // GIVEN
        input = [[
            .init(word: .init(term: "One", token: "one"), count: 3),
        ], [
            .init(word: .init(term: "Four", token: "four"), count: 5),
        ]]
        
        // WHEN
        output = sut(input)
        
        // THEN
        XCTAssertFalse(output.isEmpty)
        XCTAssertEqual(output.count, 2)
        XCTAssertEqual(output, [
            .init(word: .init(term: "Four", token: "four"), count: 5),
            .init(word: .init(term: "One", token: "one"), count: 3)
        ])
    }
    
    func testCallAsFunction_withEmptyInput() {
        // GIVEN
        input = []
        
        // WHEN
        output = sut(input)
        
        // THEN
        XCTAssertTrue(output.isEmpty)
        XCTAssertEqual(output, [])
    }
    
}
