//
//  FullWidthModifier.swift
//  ReviewsUIKit
//
//  Created by Javier Cicchelli on 19/03/2024.
//  Copyright © 2024 Röck+Cöde VoF. All rights reserved.
//

import SwiftUI

struct FullWidthModifier: ViewModifier {
    
    // MARK: Constants
    private let alignment: Alignment
    
    // MARK: Initialisers
    init(alignment: Alignment) {
        self.alignment = alignment
    }
    
    // MARK: Functions
    func body(content: Content) -> some View {
        content
            .frame(
                maxWidth: .infinity,
                alignment: alignment
            )
    }
    
}

// MARK: - Previews
#Preview {
    Group {
        Text("Hello, world!")
            .modifier(FullWidthModifier(alignment: .leading))
        Text("Hello, world!")
            .modifier(FullWidthModifier(alignment: .center))
        Text("Hello, world!")
            .modifier(FullWidthModifier(alignment: .trailing))
    }
    .padding(.horizontal)
}
